aboutsummaryrefslogtreecommitdiff
path: root/libjava/java/text
diff options
context:
space:
mode:
authorIto Kazumitsu <kaz@maczuka.gcd.org>2004-07-10 08:55:22 +0000
committerMichael Koch <mkoch@gcc.gnu.org>2004-07-10 08:55:22 +0000
commit8f0ce8da14c75a8b60721cc5e813505599c46715 (patch)
tree905361c6d0df010ab5ebeddd8423a624910958a6 /libjava/java/text
parentb352098021d0d7be6f551de3c3ea80979f2e88e9 (diff)
downloadgcc-8f0ce8da14c75a8b60721cc5e813505599c46715.zip
gcc-8f0ce8da14c75a8b60721cc5e813505599c46715.tar.gz
gcc-8f0ce8da14c75a8b60721cc5e813505599c46715.tar.bz2
2004-07-10 Ito Kazumitsu <kaz@maczuka.gcd.org>
* java/text/MessageFormat.java (formatInternal): Append "{n}" if argument n is unavailable. (format(Object, StringBuffer, FieldPosition)): This should be equivalent to format(Object[], StringBuffer, FieldPosition). From-SVN: r84448
Diffstat (limited to 'libjava/java/text')
-rw-r--r--libjava/java/text/MessageFormat.java69
1 files changed, 33 insertions, 36 deletions
diff --git a/libjava/java/text/MessageFormat.java b/libjava/java/text/MessageFormat.java
index 2e1786da..b123412 100644
--- a/libjava/java/text/MessageFormat.java
+++ b/libjava/java/text/MessageFormat.java
@@ -1,5 +1,5 @@
/* MessageFormat.java - Localized message formatting.
- Copyright (C) 1999, 2001, 2002 Free Software Foundation, Inc.
+ Copyright (C) 1999, 2001, 2002, 2004 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -157,7 +157,7 @@ public class MessageFormat extends Format
* This is the attribute set for all characters produced
* by MessageFormat during a formatting.
*/
- public static final MessageFormat.Field ARGUMENT = new Field("argument");
+ public static final MessageFormat.Field ARGUMENT = new MessageFormat.Field("argument");
// For deserialization
private Field()
@@ -414,10 +414,13 @@ public class MessageFormat extends Format
for (int i = 0; i < elements.length; ++i)
{
- if (elements[i].argNumber >= arguments.length)
- throw new IllegalArgumentException("Not enough arguments given");
+ Object thisArg = null;
+ boolean unavailable = false;
+ if (arguments == null || elements[i].argNumber >= arguments.length)
+ unavailable = true;
+ else
+ thisArg = arguments[elements[i].argNumber];
- Object thisArg = arguments[elements[i].argNumber];
AttributedCharacterIterator iterator = null;
Format formatter = null;
@@ -425,22 +428,27 @@ public class MessageFormat extends Format
if (fp != null && i == fp.getField() && fp.getFieldAttribute() == Field.ARGUMENT)
fp.setBeginIndex(appendBuf.length());
- if (elements[i].setFormat != null)
- formatter = elements[i].setFormat;
- else if (elements[i].format != null)
+ if (unavailable)
+ appendBuf.append("{" + elements[i].argNumber + "}");
+ else
{
- if (elements[i].formatClass != null
- && ! elements[i].formatClass.isInstance(thisArg))
- throw new IllegalArgumentException("Wrong format class");
+ if (elements[i].setFormat != null)
+ formatter = elements[i].setFormat;
+ else if (elements[i].format != null)
+ {
+ if (elements[i].formatClass != null
+ && ! elements[i].formatClass.isInstance(thisArg))
+ throw new IllegalArgumentException("Wrong format class");
- formatter = elements[i].format;
+ formatter = elements[i].format;
+ }
+ else if (thisArg instanceof Number)
+ formatter = NumberFormat.getInstance(locale);
+ else if (thisArg instanceof Date)
+ formatter = DateFormat.getTimeInstance(DateFormat.DEFAULT, locale);
+ else
+ appendBuf.append(thisArg);
}
- else if (thisArg instanceof Number)
- formatter = NumberFormat.getInstance(locale);
- else if (thisArg instanceof Date)
- formatter = DateFormat.getTimeInstance(DateFormat.DEFAULT, locale);
- else
- appendBuf.append(thisArg);
if (fp != null && fp.getField() == i && fp.getFieldAttribute() == Field.ARGUMENT)
fp.setEndIndex(appendBuf.length());
@@ -496,29 +504,18 @@ public class MessageFormat extends Format
}
/**
- * Returns the pattern with the formatted objects.
+ * Returns the pattern with the formatted objects. The first argument
+ * must be a array of Objects.
+ * This is equivalent to format((Object[]) objectArray, appendBuf, fpos)
*
* @param source The object to be formatted.
* @param result The StringBuffer where the text is appened.
* @param fpos A FieldPosition object (it is ignored).
*/
- public final StringBuffer format (Object singleArg, StringBuffer appendBuf,
+ public final StringBuffer format (Object objectArray, StringBuffer appendBuf,
FieldPosition fpos)
{
- Object[] args;
-
- if (singleArg instanceof Object[])
- {
- // This isn't specified in any manual, but it follows the
- // JDK implementation.
- args = (Object[]) singleArg;
- }
- else
- {
- args = new Object[1];
- args[0] = singleArg;
- }
- return format (args, appendBuf, fpos);
+ return format ((Object[])objectArray, appendBuf, fpos);
}
/**
@@ -496,29 +504,18 @@ public class MessageFormat extends Format
*
- * @param source The object to be formatted.
- * @param result The StringBuffer where the text is appened.
+ * @param objectArray The object array to be formatted.
+ * @param appendBuf The StringBuffer where the text is appened.
* @param fpos A FieldPosition object (it is ignored).
*/